import setuptools 
setuptools.setup(
    name='xandar', 
    version='0.4', 
    author="ADITYA PANAYAL", 
    author_email="adpanayal@gmail.com", 
    description="A simple calculator", 
    packages=setuptools.find_packages(), 
    classifiers=[ "Programming Language :: Python :: 3", 
    "License :: OSI Approved :: MIT License", 
    "Operating System :: OS Independent", ], 
)